@@ -7,6 +7,7 @@
 """
 import os
 import time
+import cgi
 
 import gtk
 import hildon
@@ -25,6 +26,7 @@ import contacts as ContactH
 import logging
 log = logging.getLogger('fmms.%s' % __name__)
 
+
 class fMMS_GUI(hildon.Program):
 
 	def __init__(self):
@@ -33,7 +35,7 @@ class fMMS_GUI(hildon.Program):
 		self._mmsdir = self.config.get_mmsdir()
 		self._pushdir = self.config.get_pushdir()
 		self.ch = ContactH.ContactHandler()
-		self.osso_c = osso.Context("fMMS", "0.1.0", False)
+		self.osso_c = osso.Context("fMMS", self.config.get_version(), False)
 	
 		if not os.path.isdir(self._mmsdir):
 			log.info("creating dir %s", self._mmsdir)
@@ -55,8 +57,7 @@ class fMMS_GUI(hildon.Program):
 		self.window.connect("delete_event", self.quit)
 		
 		pan = hildon.PannableArea()
-		pan.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
-		
+		pan.set_property("mov-mode", hildon.MOVEMENT_MODE_VERT)
 		
 		### TODO: dont hardcode the values here.. oh well
 		iconcell = gtk.CellRendererPixbuf()
@@ -68,19 +69,17 @@ class fMMS_GUI(hildon.Program):
 		photocell.set_property('xalign', 1.0)
 		photocell.set_fixed_size(64, 64)
 		textcell.set_property('mode', gtk.CELL_RENDERER_MODE_INERT)
-		textcell.set_fixed_size(650, 64)
+		textcell.set_fixed_size(610, 64)
 		textcell.set_property('xalign', 0.0)
 		
-		self.liststore = gtk.ListStore(gtk.gdk.Pixbuf, str, gtk.gdk.Pixbuf, str)
-		self.treeview = hildon.GtkTreeView(gtk.HILDON_UI_MODE_EDIT)
+		self.liststore = gtk.ListStore(gtk.gdk.Pixbuf, str, gtk.gdk.Pixbuf, str, str)
+		self.treeview = hildon.GtkTreeView(gtk.HILDON_UI_MODE_NORMAL)
 		self.treeview.set_model(self.liststore)
-
 		
 		icon_col = gtk.TreeViewColumn('Icon')
 		sender_col = gtk.TreeViewColumn('Sender')
 		placeholder_col = gtk.TreeViewColumn('Photo')
 		
-		
 		self.add_buttons_liststore()
 		
 		self.treeview.append_column(icon_col)
@@ -94,18 +93,38 @@ class fMMS_GUI(hildon.Program):
 		placeholder_col.pack_end(photocell, False)
 		placeholder_col.set_attributes(photocell, pixbuf=2)
 		
-		selection = self.treeview.get_selection()
-		#selection.set_mode(gtk.SELECTION_SINGLE)
+		#self.liststore_menu = self.liststore_mms_menu()
+		#self.treeview.tap_and_hold_setup(self.liststore_menu)
 		self.treeview.connect('hildon-row-tapped', self.show_mms)
 		
+		mmsBox = gtk.HBox()
+		icon_theme = gtk.icon_theme_get_default()
+		envelopePixbuf = icon_theme.load_icon("general_sms_button", 48, 0)
+		envelopeImage = gtk.Image()
+		envelopeImage.set_from_pixbuf(envelopePixbuf)
+		envelopeImage.set_alignment(1, 0.5)
+		mmsLabel = gtk.Label("New MMS")
+		mmsLabel.set_alignment(0, 0.5)
 		
-		self.liststore_menu = self.liststore_mms_menu()
-		self.treeview.tap_and_hold_setup(self.liststore_menu)
-		#treeview.connect('tap-and-hold', self.liststore_mms_clicked)
+		mmsBox.pack_start(envelopeImage, True, True, 0)
+		mmsBox.pack_start(mmsLabel, True, True, 0)
+		newMsgButton = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
 		
+		newMsgButton.add(mmsBox)
+		newMsgButton.connect('clicked', self.new_mms_button_clicked)
+		#newMsgButton.set_size_request(0, 0)
 		
-		pan.add_with_viewport(self.treeview)
-		self.window.add(pan)
+		hugeBox = gtk.VBox()
+		hugeBox.pack_start(newMsgButton, False, False, 0)
+		#hugeBox.pack_start(self.treeview, True, True, 0)
+		pan.add(self.treeview)
+		hugeBox.pack_start(pan, True, True, 0)
+
+		align = gtk.Alignment(1, 1, 1, 1)
+		align.set_padding(2, 2, 10, 10)		
+		align.add(hugeBox)
+		
+		self.window.add(align)
 	
 		self.menu = self.create_menu()
 		self.window.set_app_menu(self.menu)
@@ -121,13 +140,15 @@ class fMMS_GUI(hildon.Program):
 			note.system_note_dialog(firstlaunchmessage , 'notice')
 			self.create_config_dialog()
 			self.config.set_firstlaunch(0)
-	
+		
+		
 	def cb_on_focus(self, widget, event):
-		# TODO: re-set iter
-		#log.info("got focus")
-		#self.liststore.clear()
-		#self.add_buttons_liststore()
-		pass
+		#(model, itera) = self.treeview.get_selection().get_selected()
+		self.liststore.clear()
+		self.add_buttons_liststore()
+		#pass
+		return True
+	
 	
 	def cb_open_fmms(self, interface, method, args, user_data):
 		if method != 'open_mms' and method != 'open_gui':
@@ -136,7 +157,7 @@ class fMMS_GUI(hildon.Program):
 			filename = args[0]
 			if self.cont.is_fetched_push_by_transid(filename):
 				hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
-				banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Opening message")
+				#banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Opening message")
 				self.force_ui_update()
 				viewer = fMMSViewer.fMMS_Viewer(filename)
 				hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
@@ -152,13 +173,10 @@ class fMMS_GUI(hildon.Program):
 			fMMSSenderUI.fMMS_SenderUI(tonumber=args[0]).run()
 			return
 		
+		
 	def create_menu(self):
 		menu = hildon.AppMenu()
 		
-		send = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
-		send.set_label("New MMS")
-		send.connect('clicked', self.menu_button_clicked)
-		
 		config = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
 		config.set_label("Configuration")
 		config.connect('clicked', self.menu_button_clicked)
@@ -167,7 +185,6 @@ class fMMS_GUI(hildon.Program):
 		about.set_label("About")
 		about.connect('clicked', self.menu_button_clicked)
 		
-		menu.append(send)
 		menu.append(config)
 		menu.append(about)
 		
@@ -175,14 +192,18 @@ class fMMS_GUI(hildon.Program):
 		
 		return menu
 		
+		
 	def menu_button_clicked(self, button):
 		buttontext = button.get_label()
 		if buttontext == "Configuration":
 			ret = self.create_config_dialog()
-		elif buttontext == "New MMS":
-			ret = fMMSSenderUI.fMMS_SenderUI(self.window).run()
 		elif buttontext == "About":
 			ret = self.create_about_dialog()
+	
+	
+	def new_mms_button_clicked(self, button):
+		ret = fMMSSenderUI.fMMS_SenderUI(self.window).run()
+		
 		
 	def create_about_dialog(self):
 		dialog = gtk.AboutDialog()                                                 
@@ -196,6 +217,7 @@ class fMMS_GUI(hildon.Program):
 		dialog.connect("response", lambda d, r: d.destroy())                      
 		dialog.show() 
  
+
 	def create_config_dialog(self):
 		dialog = gtk.Dialog()
 		dialog.set_title("Configuration")
@@ -204,8 +226,11 @@ class fMMS_GUI(hildon.Program):
 		
 		self.active_apn_index = 0
 		
+		labelwidth = 16
+		
 		apnHBox = gtk.HBox()
 		apn_label = gtk.Label("APN:")
+		apn_label.set_width_chars(labelwidth)
 		self.selector = self.create_apn_selector()
 		self.apn = hildon.PickerButton(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
 		self.apn.set_selector(self.selector)
@@ -216,6 +241,7 @@ class fMMS_GUI(hildon.Program):
 		
 		mmscHBox = gtk.HBox()
 		mmsc_label = gtk.Label("MMSC:")
+		mmsc_label.set_width_chars(labelwidth)
 		self.mmsc = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
 		mmsc_text = self.config.get_mmsc()
 		if mmsc_text != None:	
@@ -227,6 +253,7 @@ class fMMS_GUI(hildon.Program):
 		
 		numberHBox = gtk.HBox()
 		number_label = gtk.Label("Your phonenumber:")
+		number_label.set_width_chars(labelwidth)
 		self.number = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
 		number_text = self.config.get_phonenumber()
 		if number_text != None:
@@ -238,6 +265,7 @@ class fMMS_GUI(hildon.Program):
 		
 		imgwidthHBox = gtk.HBox()
 		imgwidth_label = gtk.Label("Resize image width:")
+		imgwidth_label.set_width_chars(labelwidth)
 		self.imgwidth = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
 		imgwidth_text = self.config.get_img_resize_width()
 		if imgwidth_text != None:
@@ -247,9 +275,9 @@ class fMMS_GUI(hildon.Program):
 		imgwidthHBox.pack_start(imgwidth_label, False, True, 0)
 		imgwidthHBox.pack_start(self.imgwidth, True, True, 0)
 		
-		notelabel = gtk.Label("APN refers to the name of the connection in\n \"Internet Connections\" to use.")
+		#notelabel = gtk.Label("APN refers to the name of the connection in\n \"Internet Connections\" to use.")
 		
-		allVBox.pack_start(notelabel, False, True, 0)
+		#allVBox.pack_start(notelabel, False, True, 0)
 		allVBox.pack_start(apnHBox, False, False, 0)
 		allVBox.pack_start(mmscHBox, False, False, 0)
 		allVBox.pack_end(numberHBox, False, False, 0)
@@ -314,25 +342,31 @@ class fMMS_GUI(hildon.Program):
 				banner = hildon.hildon_banner_show_information(self.window, "", "Could not save APN settings. Did you enter a correct APN?")
 				banner.set_timeout(5000)
 				return -1
-		
+
 
 	""" add each item to our liststore """
 	def add_buttons_liststore(self):
 			icon_theme = gtk.icon_theme_get_default()
 			
 			pushlist = self.cont.get_push_list()
+			
+			primarytxt = self.cont.get_primary_font().to_string()
+			primarycolor = self.cont.get_primary_color().to_string()
+			secondarytxt = self.cont.get_secondary_font().to_string()
+			secondarycolor = self.cont.get_secondary_color().to_string()
 			for varlist in pushlist:
-				mtime = varlist['Time']
+                                mtime = varlist['Time']
+                                # TODO: Remove date if date == today
+                                # TODO: get locale format?
+                                mtime = time.strptime(mtime, "%Y-%m-%d %H:%M:%S")
+                                mtime = time.strftime("%Y-%m-%d | %H:%M", mtime)
+
 				fname = varlist['Transaction-Id']
 				direction = self.cont.get_direction_mms(fname)
-				# TODO Use fancy icon for showing read/unread
-				
-				
+
+				isread = False
 				if self.cont.is_mms_read(fname):
-					isread = " (Read)"
-				else:
-					isread = " (Unread)"
-				
+					isread = True
 				
 				try:
 					sender = varlist['From']
@@ -341,24 +375,37 @@ class fMMS_GUI(hildon.Program):
 					sender = "0000000"
 				
 				if direction == fMMSController.MSG_DIRECTION_OUT:
-					sender = "You (Outgoing)"
+					# TODO: Change to show receivers name
+					sender = "You"
 				
 				sendername = self.ch.get_name_from_number(sender)
 				photo = icon_theme.load_icon("general_default_avatar", 48, 0)
 				if sendername != None:
-					sender = sendername + ' <span size="smaller">(' + sender + ')</span>'
-					phototest = self.ch.get_photo_from_name(sendername, 64)
+					sender = sendername
+					phototest = self.ch.get_photo_from_name(sendername, 48)
 					if phototest != None:	
 						photo = phototest
-						#log.info("loaded photo: %s %s", photo.get_width(), photo.get_height())
-	
-				#title = sender + " - " + mtime
 				
-				if self.cont.is_fetched_push_by_transid(fname):
+				if direction == fMMSController.MSG_DIRECTION_OUT:
+					icon = icon_theme.load_icon("chat_replied_sms", 48, 0)
+				elif self.cont.is_fetched_push_by_transid(fname) and isread:
 					icon = icon_theme.load_icon("general_sms", 48, 0)
 				else:
 					icon = icon_theme.load_icon("chat_unread_sms", 48, 0)
-				self.liststore.append([icon, sender + isread + '  <span foreground="#666666" size="smaller"><sup>' + mtime + '</sup></span>\n<span foreground="#666666" size="x-small">' + fname + '</span>', photo, fname])
+					
+				try:
+					headerlist = self.cont.get_mms_headers(fname)
+					description = cgi.escape(headerlist['Description'])
+				except:
+					try:
+						description = varlist['Subject']
+					except:
+						description = ""
+				primarytext = ' <span font_desc="%s" foreground="%s"><sup>%s</sup></span>' % (secondarytxt, secondarycolor, mtime)
+				secondarytext = '\n<span font_desc="%s" foreground="%s">%s</span>' % (secondarytxt, secondarycolor, description)
+				stringline = sender + primarytext + secondarytext
+				self.liststore.append([icon, stringline, photo, fname, sender])
+
 	
 	""" lets call it quits! """
 	def quit(self, *args):
@@ -379,6 +426,7 @@ class fMMS_GUI(hildon.Program):
 	""" delete mms message (eg for redownload) """
 	def delete_mms(self, fname):
 		self.cont.delete_mms_message(fname)
+
 	
 	""" delete push & mms """
 	def delete_push_mms(self, fname):
@@ -393,6 +441,13 @@ class fMMS_GUI(hildon.Program):
 
 	""" action on delete contextmenu click """
 	def liststore_delete_clicked(self, widget):
+		selection = self.treeview.get_selection()
+		(model, miter) = selection.get_selected()
+		print model, miter
+		# the 4th value is the transactionid (start counting at 0)
+		filename = model.get_value(miter, 3)
+		print filename
+		
 		dialog = gtk.Dialog()
 		dialog.set_title("Confirm")
 		dialog.add_button(gtk.STOCK_YES, 1)
@@ -402,63 +457,17 @@ class fMMS_GUI(hildon.Program):
 		dialog.show_all()
 		ret = dialog.run()
 		if ret == 1:
-			(model, miter) = self.treeview.get_selection().get_selected()
-			# the 4th value is the filename (start counting at 0)
-			filename = model.get_value(miter, 3)
 			log.info("deleting %s", filename)
 			self.delete_push_mms(filename)
-			self.liststore.remove(miter)
+			#self.liststore.remove(miter)
 		dialog.destroy()
 		return
 	
-	""" action on redl contextmenu click """
-	def liststore_redl_clicked(self, widget):
-		hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
-		dialog = gtk.Dialog()
-		dialog.set_title("WARNING")
-		dialog.add_button(gtk.STOCK_YES, 1)
-		dialog.add_button(gtk.STOCK_NO, 0)
-		label = gtk.Label("If the message is no longer on your MMSC,\n the message will be lost. Continue?")
-		dialog.vbox.add(label)
-		dialog.show_all()
-		ret = dialog.run()
-		dialog.destroy()
-		self.force_ui_update()
-		
-		if ret == 1:
-			(model, miter) = self.treeview.get_selection().get_selected()
-			# the 4th value is the filename (start counting at 0)
-			filename = model.get_value(miter, 3)
-			log.info("redownloading %s", filename)
-			try:
-				self.delete_mms(filename)
-				banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Trying to download MMS...")
-				self.force_ui_update()
-				
-				# TODO: FIXME
-				
-				self.cont.get_mms_from_push(filename)
-				self.show_mms(self.treeview, model.get_path(miter))
-			except Exception, e:
-				log.exception("%s %s", type(e), e)
-				#raise
-				banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Operation failed")
-			hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
-		return
 
 	""" long press on image creates this """
 	def liststore_mms_menu(self):
 		menu = gtk.Menu()
-		menu.set_title("hildon-context-sensitive-menu")
-
-		redlItem = gtk.MenuItem("Redownload")
-		menu.append(redlItem)
-		redlItem.connect("activate", self.liststore_redl_clicked)
-		redlItem.show()
-		
-		separator = gtk.MenuItem()
-		menu.append(separator)
-		separator.show()
+		menu.set_property("name", "hildon-context-sensitive-menu")
 		
 		openItem = gtk.MenuItem("Delete")
 		menu.append(openItem)
@@ -468,11 +477,11 @@ class fMMS_GUI(hildon.Program):
 		menu.show_all()
 		return menu
 
+
 	""" show the selected mms """		
 	def show_mms(self, treeview, path):
 		# Show loading indicator
 		hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
-		banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Opening message")
 		self.force_ui_update()
 		
 		log.info("showing mms: %s", path)
@@ -486,14 +495,13 @@ class fMMS_GUI(hildon.Program):
 		except Exception, e:
 			log.exception("%s %s", type(e), e)
 			#raise
-		
-		
 		hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
 
+
 	def run(self):
 		self.window.show_all()
 		gtk.main()
-		
+				
 if __name__ == "__main__":
 	app = fMMS_GUI()
 	app.run()
\ No newline at end of file
