@@ -65,6 +65,7 @@ class fMMS_SenderUI(hildon.Program):
 		pan.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)		
 		
 		self.tvMessage = hildon.TextView()
+		self.tvMessage.set_property("name", "hildon-fullscreen-textview")
 		self.tvMessage.set_wrap_mode(gtk.WRAP_WORD)
 		
 		pan.add_with_viewport(self.tvMessage)
@@ -72,19 +73,25 @@ class fMMS_SenderUI(hildon.Program):
 		""" Begin botsection """
 		
 		botHBox = gtk.HBox()
+		#botHBox.set_homogeneous(True)
 		#self.bAttachment = gtk.FileChooserButton('')
 		#self.bAttachment.connect('file-set', self.update_size)
 		self.bAttachment = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "Attachment")
 		self.bAttachment.connect('clicked', self.open_file_dialog)
+		self.attachmentFile = ""
 		
-		self.lSize = gtk.Label('')
+		self.lSize = gtk.Label()
+		#self.lSize.set_markup("Size:\n<small>0 kB</small>")
+		self.lSize.set_width_chars(36)
+		self.lSize.set_alignment(0.5, 0.5)
 		
-		self.bSend = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "    Send    ")
+		
+		self.bSend = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "Send")
 		self.bSend.connect('clicked', self.send_mms_clicked)
 		
-		botHBox.pack_start(self.bAttachment)
-		botHBox.pack_start(self.lSize)
-		botHBox.pack_end(self.bSend, False, False, 5)
+		botHBox.pack_start(self.bAttachment, True, True, 0)
+		botHBox.pack_start(self.lSize, True, True, 0)
+		botHBox.pack_start(self.bSend, True, True, 0)
 		
 
 		""" Show it all! """
@@ -92,7 +99,11 @@ class fMMS_SenderUI(hildon.Program):
 		allBox.pack_start(pan, True, True)
 		allBox.pack_start(botHBox, False, False)
 		
-		self.window.add(allBox)
+		align = gtk.Alignment(1, 1, 1, 1)
+		align.set_padding(2, 2, 10, 10)		
+		align.add(allBox)
+		
+		self.window.add(align)
 		self.window.show_all()
 		self.add_window(self.window)
 	
@@ -185,8 +196,9 @@ class fMMS_SenderUI(hildon.Program):
 				banner = hildon.hildon_banner_show_information(self.window, "", "10MB attachment limit in effect, please try another file")
 				self.bAttachment.set_label("Attachment")
 			else:
-				self.bAttachment.set_label(fcd.get_filename())
-				self.update_size(fcd.get_filename())
+				self.bAttachment.set_label(os.path.basename(fcd.get_filename()))
+				#self.update_size(fcd.get_filename())
+				self.attachmentFile = fcd.get_filename()
 			fcd.destroy()
 		else:
 			fcd.destroy()
@@ -249,8 +261,8 @@ class fMMS_SenderUI(hildon.Program):
 			note.system_note_dialog("Invalid phonenumber, must only contain + and digits" , 'notice')
 			return
 		
-		attachment = self.bAttachment.get_label()
-		if attachment == "Attachment" or attachment == None:
+		attachment = self.attachmentFile
+		if attachment == "" or attachment == None:
 			attachment = None
 			self.attachmentIsResized = False
 		else:
@@ -277,7 +289,10 @@ class fMMS_SenderUI(hildon.Program):
 		# TODO: remove hardcoded subject
 		# TODO: let controller do this
 		try:
-			sender = MMSSender(to, "MMS", message, attachment, sender)
+			subject = message[:10]
+			if len(message) > 10:
+				subject += "..."
+			sender = MMSSender(to, subject, message, attachment, sender)
 			(status, reason, output) = sender.sendMMS()
 			### TODO: Clean up and make this look decent
 			message = str(status) + "_" + str(reason)
@@ -314,12 +329,12 @@ class fMMS_SenderUI(hildon.Program):
 			os.remove(attachment)
 		#self.window.destroy()
 		
-	def update_size(self, fname):
+	"""def update_size(self, fname):
 		try:
 			size = os.path.getsize(fname) / 1024
-			self.lSize.set_markup("Size:\n<small>" + str(size) + "kB</small>")	
+			self.lSize.set_markup("Size:\n<small>" + str(size) + " kB</small>")	
 		except TypeError:
-			self.lSize.set_markup("")
+			self.lSize.set_markup("Size:\n<small>0 kB</small>")"""
 
 	def quit(self, *args):
 		gtk.main_quit()
