@@ -7,6 +7,7 @@
 """
 import os
 import sys
+import time
 
 import gtk
 import hildon
@@ -19,6 +20,7 @@ from wappushhandler import PushHandler
 import fmms_config as fMMSconf
 import controller as fMMSController
 import fmms_sender_ui as fMMSSenderUI
+import contacts as ContactH
 
 import logging
 log = logging.getLogger('fmms.%s' % __name__)
@@ -27,6 +29,7 @@ class fMMS_Viewer(hildon.Program):
 
 	def __init__(self, fname, standalone=False):
 		self.cont = fMMSController.fMMS_controller()
+		self.ch = ContactH.ContactHandler()
 		self.standalone = standalone
 		self.config = fMMSconf.fMMS_config()
 		self._mmsdir = self.config.get_mmsdir()
@@ -35,19 +38,21 @@ class fMMS_Viewer(hildon.Program):
 		self.osso_c = osso.Context("fMMS", "0.1.0", False)
 		
 		self.window = hildon.StackableWindow()
-		self.window.set_title("Showing MMS: " + fname)
+		self.window.set_title("Showing MMS")
 		self.window.connect("delete_event", self.quit)
 		
 		vbox = gtk.VBox()
 		pan = hildon.PannableArea()
 		pan.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
 
+		self._direction = self.cont.get_direction_mms(fname)
+
 		self._parse_mms(fname, vbox)
 
 		pan.add_with_viewport(vbox)
 		self.window.add(pan)
 
-		if not self.cont.is_mms_read(fname) and self.cont.get_direction_mms(fname) == fMMSController.MSG_DIRECTION_IN:
+		if not self.cont.is_mms_read(fname) and self._direction == fMMSController.MSG_DIRECTION_IN:
 			self.cont.mark_mms_read(fname)
 
 		mms_menu = self.create_mms_menu(fname)
@@ -77,14 +82,53 @@ class fMMS_Viewer(hildon.Program):
 		reply.set_label("Reply")
 		reply.connect('clicked', self.mms_menu_button_clicked, fname)
 		
+		delete = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+		delete.set_label("Delete")
+		delete.connect('clicked', self.mms_menu_button_clicked, fname)
+		
 		menu.append(reply)
 		menu.append(headers)
+		menu.append(delete)
 	
 		menu.show_all()
 		
 		return menu		
 	
 	
+	def delete_dialog(self, filename):
+		dialog = gtk.Dialog()
+		dialog.set_title("Confirm")
+		dialog.add_button(gtk.STOCK_YES, 1)
+		dialog.add_button(gtk.STOCK_NO, 0)
+		label = gtk.Label("Are you sure you want to delete the message?")
+		dialog.vbox.add(label)
+		dialog.show_all()
+		ret = dialog.run()
+		if ret == 1:
+			hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
+			banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Trying to delete message")
+			banner.set_timeout(3000)
+			self.force_ui_update()
+			log.info("deleting %s", filename)
+			self.force_ui_update()
+			self.delete_push_mms(filename)
+		dialog.destroy()
+	
+	
+	""" delete push & mms """
+	def delete_push_mms(self, fname):
+		log.info("deleting message: %s", fname)
+		try:
+			self.cont.wipe_message(fname)
+			banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Message deleted")
+			self.force_ui_update()
+			self.window.destroy()
+		except Exception, e:
+			log.exception("%s %s", type(e), e)
+			banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Failed to delete message.")
+		
+	
+	
 	""" actions for mms menu """
 	def mms_menu_button_clicked(self, button, fname):
 		buttontext = button.get_label()
@@ -93,6 +137,8 @@ class fMMS_Viewer(hildon.Program):
 		elif buttontext == "Reply":
 			number = self.cont.get_replyuri_from_transid(fname)
 			fMMSSenderUI.fMMS_SenderUI(tonumber=number).run()
+		elif buttontext == "Delete":
+			self.delete_dialog(fname)
 
 	""" show headers in a dialog """
 	def create_headers_dialog(self, fname):
@@ -135,15 +181,75 @@ class fMMS_Viewer(hildon.Program):
 		hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
 		self.force_ui_update()
 		
-		if not self.cont.is_fetched_push_by_transid(filename):	
+		if not self.cont.is_fetched_push_by_transid(filename):
+			banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Trying to download MMS...")
+			self.force_ui_update()
 			self.cont.get_mms_from_push(filename)
 				
+
+		headerlist = self.cont.get_mms_headers(filename)
+		sender = headerlist['From'].replace("/TYPE=PLMN", "")
+		sendername = self.ch.get_name_from_number(sender)
+		if sendername != None:
+			sender = sendername
+			
+          	self.window.set_title("MMS - " + str(sender))
+		topbox = gtk.HBox()
+		if self._direction == fMMSController.MSG_DIRECTION_IN:
+			label = gtk.Label('<span foreground="#666666">From</span>')
+			sender = headerlist['From'].replace("/TYPE=PLMN", "")
+		else:
+			label = gtk.Label('<span foreground="#666666">To</span>')
+			sender = headerlist['To'].replace("/TYPE=PLMN", "")
+		
+		label.set_use_markup(True)
+		label.set_alignment(0, 0.5)
+
+		sendername = self.ch.get_name_from_number(sender)
+		if sendername != None:
+			sender = sendername
+
+		self.window.set_title("MMS - " + str(sender))
+
+		namelabel = gtk.Label(sender)
+                #namelabel.set_justification(gtk.JUSTIFY_LEFT)
+                namelabel.set_alignment(0, 0.5)
+
+                mtime = headerlist['Time']
+		try:
+			mtime = time.strptime(mtime)
+		except ValueError, e:
+			mtime = time.strptime(mtime, "%Y-%m-%d %H:%M:%S")
+		except Exception, e:
+			log.exception("%s %s", type(e), e)
+			pass
+			
+		mtime = time.strftime("%Y-%m-%d | %H:%M", mtime)
+                timestring = '<span foreground="#666666">' + mtime + "</span>"
+                timelabel = gtk.Label(timestring)
+                timelabel.set_use_markup(True)
+                timelabel.set_alignment(1, 0.5)
+                
+		topbox.pack_start(label, False, False, 20)
+		topbox.pack_start(namelabel, True, True, 0)
+		topbox.pack_end(timelabel, False, False, 10)
+		
+		container.pack_start(topbox, False, False, 5)
+		sep = gtk.HSeparator()
+		container.pack_start(sep, False, False, 0)
+		# TODO: add correct padding to first item in next container
+				
 		textview = gtk.TextView()
 		textview.set_editable(False)
 		textview.set_cursor_visible(False)
 		textview.set_wrap_mode(gtk.WRAP_WORD)
+		textview.set_justification(gtk.JUSTIFY_CENTER)
+		black = gtk.gdk.Color(red=0, green=0, blue=0)
+		textview.modify_base(gtk.STATE_NORMAL, black)
+		textview.modify_text(gtk.STATE_NORMAL, gtk.gdk.color_parse("white"))
 		textbuffer = gtk.TextBuffer()
 		direction = self.cont.get_direction_mms(filename)
+		# TODO: get from db instead
 		if direction == fMMSController.MSG_DIRECTION_OUT:
 			path = self._outdir + filename
 		else:
@@ -190,7 +296,7 @@ class fMMS_Viewer(hildon.Program):
 				container.pack_end(attachButton, False, False, 0)
 				
 		textview.set_buffer(textbuffer)
-		container.add(textview)
+		container.pack_start(textview)
 		hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
 		
 		
@@ -223,7 +329,7 @@ class fMMS_Viewer(hildon.Program):
 	""" long press on image creates this """
 	def mms_img_menu(self, data=None):
 		menu = gtk.Menu()
-		menu.set_title("hildon-context-sensitive-menu")
+		menu.set_property("name", "hildon-context-sensitive-menu")
 
 		openItem = gtk.MenuItem("Open")
 		menu.append(openItem)
